## Copyright (C) 2010-2016   Lukas F. Reichlin
##
## This program is free software: you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation, either version 3 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program.  If not, see <http://www.gnu.org/licenses/>.

## -*- texinfo -*-
## @deftypefn {Function File} {@var{q} =} round (@var{q})
## Round the components of quaternion @var{q} towards the nearest integers.
## @end deftypefn

## Author: Lukas Reichlin <lukas.reichlin@gmail.com>
## Created: December 2013
## Version: 0.1

function q = round (q)

  if (nargin != 1)
    print_usage ();
  endif
  
  q.w = builtin ("round", q.w);
  q.x = builtin ("round", q.x);
  q.y = builtin ("round", q.y);
  q.z = builtin ("round", q.z);

endfunction


%!test
%! q = quaternion (1.4, 2.6, 3.5, 4.2);
%! result = round (q);
%! expected = quaternion (1, 3, 4, 4);
%! assert (result == expected);
